==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack.md <==
# AmazonLocationServiceTrack


```text
aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack
```

```text
include('aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')
```



| Illustration | AmazonLocationServiceTrack | AmazonLocationServiceTrackCard | AmazonLocationServiceTrackGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack.png) | ![illustration for AmazonLocationServiceTrack](../../../aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack.Local.png) | ![illustration for AmazonLocationServiceTrackCard](../../../aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrackCard.Local.png) | ![illustration for AmazonLocationServiceTrackGroup](../../../aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrackGroup.Local.png) |




## AmazonLocationServiceTrack

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrack
include('aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrack('AmazonLocationServiceTrack', 'Amazon Location Service Track', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrack
include('aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrack('AmazonLocationServiceTrack', 'Amazon Location Service Track', 'an optional tech label')
@enduml
```

## AmazonLocationServiceTrackCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrackCard
include('aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrackCard('AmazonLocationServiceTrackCard', 'Amazon Location Service Track Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrackCard
include('aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrackCard('AmazonLocationServiceTrackCard', 'Amazon Location Service Track Card', 'an optional description')
@enduml
```

## AmazonLocationServiceTrackGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrackGroup
include('aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrackGroup('AmazonLocationServiceTrackGroup', 'Amazon Location Service Track Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrackGroup
include('aws-q2-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrackGroup('AmazonLocationServiceTrackGroup', 'Amazon Location Service Track Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack.md <==
# AmazonLocationServiceTrack


```text
aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack
```

```text
include('aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')
```



| Illustration | AmazonLocationServiceTrack | AmazonLocationServiceTrackCard | AmazonLocationServiceTrackGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack.png) | ![illustration for AmazonLocationServiceTrack](../../../aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack.Local.png) | ![illustration for AmazonLocationServiceTrackCard](../../../aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrackCard.Local.png) | ![illustration for AmazonLocationServiceTrackGroup](../../../aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrackGroup.Local.png) |




## AmazonLocationServiceTrack

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrack
include('aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrack('AmazonLocationServiceTrack', 'Amazon Location Service Track', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrack
include('aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrack('AmazonLocationServiceTrack', 'Amazon Location Service Track', 'an optional tech label', 'an optional description')
@enduml
```

## AmazonLocationServiceTrackCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrackCard
include('aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrackCard('AmazonLocationServiceTrackCard', 'Amazon Location Service Track Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrackCard
include('aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrackCard('AmazonLocationServiceTrackCard', 'Amazon Location Service Track Card', 'an optional description')
@enduml
```

## AmazonLocationServiceTrackGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrackGroup
include('aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrackGroup('AmazonLocationServiceTrackGroup', 'Amazon Location Service Track Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceTrackGroup
include('aws-q1-2022/Resource/FrontEndWebMobile/AmazonLocationServiceTrack')

' renders the element
AmazonLocationServiceTrackGroup('AmazonLocationServiceTrackGroup', 'Amazon Location Service Track Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
